@@ -4,6 +4,10 @@ if have_func('rb_thread_blocking_region')
   $defs << '-DHAVE_RB_THREAD_BLOCKING_REGION'
 end
 
+if have_func('rb_thread_call_without_gvl')
+  $defs << '-DHAVE_RB_THEREAD_CALL_WITHOUT_GVL'
+end
+
 if have_header('sys/select.h')
   $defs << '-DEV_USE_SELECT'
 end
@@ -28,6 +32,10 @@ if have_header('sys/resource.h')
   $defs << '-DHAVE_SYS_RESOURCE_H'
 end
 
+if RUBY_VERSION.to_f < 1.9
+  $defs << '-DHAVE_RUBYSIG_H'
+end
+
 dir_config 'nio4r_ext'
 create_makefile 'nio4r_ext'
 
@@ -41,4 +49,4 @@ if RUBY_PLATFORM =~ /mingw|win32/
 
   makefile_contents.gsub! 'LIBS = $(LIBRUBYARG_SHARED)', 'LIBS = -lws2_32 $(LIBRUBYARG_SHARED)'
   File.open('Makefile', 'w') { |f| f.write makefile_contents }
-end
\ No newline at end of file
+end
